@@ -682,13 +682,13 @@ ErrorCode Cell::to_gds(FILE* out, double scaling, uint64_t max_points, double pr
     if (len % 2) len++;
     uint16_t buffer_start[] = {28,
                                0x0502,
-                               (uint16_t)(timestamp->tm_year + 1900),
+                               (uint16_t)(timestamp->tm_year),
                                (uint16_t)(timestamp->tm_mon + 1),
                                (uint16_t)timestamp->tm_mday,
                                (uint16_t)timestamp->tm_hour,
                                (uint16_t)timestamp->tm_min,
                                (uint16_t)timestamp->tm_sec,
-                               (uint16_t)(timestamp->tm_year + 1900),
+                               (uint16_t)(timestamp->tm_year),
                                (uint16_t)(timestamp->tm_mon + 1),
                                (uint16_t)timestamp->tm_mday,
                                (uint16_t)timestamp->tm_hour,
