@@ -5,7 +5,8 @@ Boost Software License - Version 1.0.  See the accompanying
 LICENSE file or <http://www.boost.org/LICENSE_1_0.txt>
 */
 
-#include "reference.h"
+#define __STDC_FORMAT_MACROS 1
+#define _USE_MATH_DEFINES
 
 #include <float.h>
 #include <math.h>
@@ -13,11 +14,12 @@ LICENSE file or <http://www.boost.org/LICENSE_1_0.txt>
 #include <stdio.h>
 #include <string.h>
 
-#include "allocator.h"
-#include "cell.h"
-#include "gdsii.h"
-#include "rawcell.h"
-#include "utils.h"
+#include <gdstk/allocator.hpp>
+#include <gdstk/cell.hpp>
+#include <gdstk/gdsii.hpp>
+#include <gdstk/rawcell.hpp>
+#include <gdstk/reference.hpp>
+#include <gdstk/utils.hpp>
 
 namespace gdstk {
 
@@ -426,9 +428,10 @@ ErrorCode Reference::to_gds(FILE* out, double scaling) const {
 
         if (array) {
             if (repetition.columns > UINT16_MAX || repetition.rows > UINT16_MAX) {
-                fputs(
-                    "[GDSTK] Repetition with more than 65535 columns or rows cannot be saved to a GDSII file.\n",
-                    stderr);
+                if (error_logger)
+                    fputs(
+                        "[GDSTK] Repetition with more than 65535 columns or rows cannot be saved to a GDSII file.\n",
+                        error_logger);
                 error_code = ErrorCode::InvalidRepetition;
                 buffer_array[2] = UINT16_MAX;
                 buffer_array[3] = UINT16_MAX;
