@@ -157,9 +157,7 @@ def test_rw_gds(tmpdir, sample_library):
 
     c = cells["gl_rw_gds_2"]
     assert len(c.polygons) == 2
-    assert isinstance(c.polygons[0], gdstk.Polygon) and isinstance(
-        c.polygons[1], gdstk.Polygon
-    )
+    assert isinstance(c.polygons[0], gdstk.Polygon) and isinstance(c.polygons[1], gdstk.Polygon)
 
     c = cells["gl_rw_gds_3"]
     assert len(c.references) == 1
@@ -212,9 +210,7 @@ def test_rw_gds_filter(tmpdir, sample_library):
 
     c = cells["gl_rw_gds_2"]
     assert len(c.polygons) == 2
-    assert isinstance(c.polygons[0], gdstk.Polygon) and isinstance(
-        c.polygons[1], gdstk.Polygon
-    )
+    assert isinstance(c.polygons[0], gdstk.Polygon) and isinstance(c.polygons[1], gdstk.Polygon)
 
     c = cells["gl_rw_gds_3"]
     assert len(c.references) == 1
@@ -260,6 +256,36 @@ def test_read_gds_missing_refs(tmpdir):
     assert lib2.cells[0].name == "c2"
 
 
+def test_large_layer_number(tmpdir):
+    c1 = gdstk.Cell("CELL")
+    c1.add(gdstk.rectangle((0, 0), (1, 1), 255, 256))
+    c1.add(gdstk.rectangle((0, 0), (1, 1), 50000, 50001))
+    c1.add(gdstk.rectangle((0, 0), (1, 1), 60100, 60101))
+    c1.add(gdstk.rectangle((0, 0), (1, 1), 2**16 - 1, 2**16))
+    c1.add(gdstk.rectangle((0, 0), (1, 1), 100000, 100001))
+
+    lib = gdstk.Library()
+    lib.add(c1)
+
+    expected = {
+        (255, 256),
+        (50000, 50001),
+        (60100, 60101),
+        (2**16 - 1, 2**16),
+        (100000, 100001),
+    }
+    assert lib.layers_and_datatypes() == expected
+
+    fname = str(tmpdir.join("test_large_layer_num.gds"))
+    lib.write_gds(fname)
+
+    lib2 = gdstk.read_gds(fname)
+    assert lib2.layers_and_datatypes() == expected
+
+    info = gdstk.gds_info(fname)
+    assert info["layers_and_datatypes"] == expected
+
+
 # def test_rw_oas_filter(tmpdir, sample_library):
 #     fname = str(tmpdir.join("test.oas"))
 #     sample_library.write_oas(fname)
@@ -444,9 +470,7 @@ def test_frozen_gds_with_cell_array_has_constant_hash(tmpdir):
     cell.add(gdstk.rectangle((0, 0), (100, 1000)))
     cell2 = gdstk.Cell(name="Olaf")
     cell2.add(gdstk.rectangle((0, 0), (50, 100)))
-    cell_array = gdstk.Reference(
-        cell2, columns=5, rows=2, spacing=(60, 120), origin=(1000, 0)
-    )
+    cell_array = gdstk.Reference(cell2, columns=5, rows=2, spacing=(60, 120), origin=(1000, 0))
     cell.add(cell_array)
     lib.add(cell)
     lib.write_gds(fn1, timestamp=frozen_date)
@@ -532,9 +556,9 @@ def test_roundtrip_path_ends(tmpdir: pathlib.Path):
         gds_path = gdstk.read_gds(tmpdir / "path_test.gds").top_level()[0].get_paths()[0]
         oas_path = gdstk.read_oas(tmpdir / "path_test.oas").top_level()[0].get_paths()[0]
 
-        assert (
-            path.ends == gds_path.ends and path.ends == oas_path.ends
-        ), f"expected: {path.ends}, gds: {gds_path.ends}, oas: {oas_path.ends}"
+        assert path.ends == gds_path.ends and path.ends == oas_path.ends, (
+            f"expected: {path.ends}, gds: {gds_path.ends}, oas: {oas_path.ends}"
+        )
 
 
 @pytest.mark.parametrize(
@@ -547,7 +571,7 @@ def test_roundtrip_path_ends(tmpdir: pathlib.Path):
 def test_write_min_length_path(
     write_f: Callable[[gdstk.Library, Union[str, pathlib.Path]], None],
     read_f: Callable[Union[str, pathlib.Path], gdstk.Library],
-    tmp_path: pathlib.Path
+    tmp_path: pathlib.Path,
 ):
     source = gdstk.read_oas(pathlib.Path(__file__).parent / "min_length_path.oas")
     assert source.cells[0].paths
@@ -564,7 +588,8 @@ def test_write_min_length_path(
 
 
 @pytest.mark.parametrize(
-    "simple_path", (True, False),
+    "simple_path",
+    (True, False),
 )
 @pytest.mark.parametrize(
     "write_f",
@@ -573,7 +598,7 @@ def test_write_min_length_path(
 def test_empty_path_warning(
     simple_path: bool,
     write_f: Callable[[gdstk.Library, Union[str, pathlib.Path]], None],
-    tmp_path: pathlib.Path
+    tmp_path: pathlib.Path,
 ):
     lib = gdstk.Library("test")
     tol = lib.precision / lib.unit
@@ -581,10 +606,7 @@ def test_empty_path_warning(
     # Simple paths are written to GDS & OASIS with PATH records; non-simple
     # paths are serialized as polygons.
     path = gdstk.FlexPath(
-        ((0, 0), (tol / 2, 0)),
-        width=0.01,
-        tolerance=tol,
-        simple_path=simple_path
+        ((0, 0), (tol / 2, 0)), width=0.01, tolerance=tol, simple_path=simple_path
     )
 
     cell = gdstk.Cell("top")
